@@ -1,5 +1,4 @@
 package Data::TableReader;
-$Data::TableReader::VERSION = '0.009';
 use Moo 2;
 use Try::Tiny;
 use Carp;
@@ -9,6 +8,7 @@ use Data::TableReader::Field;
 use Data::TableReader::Iterator;
 
 # ABSTRACT: Extract records from "dirty" tabular data sources
+our $VERSION = '0.012'; # VERSION
 
 
 has input               => ( is => 'rw', required => 1 );
@@ -31,7 +31,10 @@ has log                 => ( is => 'rw', trigger => sub { shift->_clear_log } );
 sub _build__file_handle {
 	my $self= shift;
 	my $i= $self->input;
-	return undef if ref($i) && (ref($i) eq "Spreadsheet::ParseExcel::Worksheet");
+	return undef if ref($i) && (
+		ref($i) eq "Spreadsheet::ParseExcel::Worksheet"
+		or ref($i) eq 'ARRAY'
+	);
 	return $i if ref($i) && (ref($i) eq 'GLOB' or ref($i)->can('read'));
 	open(my $fh, '<', $i) or croak "open($i): $!";
 	binmode $fh;
@@ -150,6 +153,13 @@ sub detect_input_format {
 		if ref($input) && ref($input)->can('get_cell');
 	return ('XLSX', workbook => $input)
 		if ref($input) && ref($input)->can('worksheets');
+	if (ref($input) eq 'ARRAY') {
+		# if user supplied single table of data, wrap it in an array to make an array of tables.
+		$input= [ $input ]
+			if @$input && ref($input->[0]) eq 'ARRAY'
+			&& @{$input->[0]} && ref($input->[0][0]) ne 'ARRAY';
+		return ('Mock', datasets => $input);
+	}
 
 	# Load first block of file, unless supplied
 	my $fpos;
@@ -495,7 +505,7 @@ sub iterator {
 	my @row_slice; # one column index per field, and possibly more for array_val_map
 	my @arrayvals; # list of source index and destination index for building array values
 	my @field_names; # ordered list of field names where row slice should be assigned
-	my @trim_idx;  # list of array indicies which should be whitespace-trimmed.
+	my %trimmer;   # list of trim functions and the array indicies they should be applied to
 	my @blank_val; # blank value per each fetched column
 	my @type_check;# list of 
 	my $class;     # optional object class for the resulting rows
@@ -523,7 +533,10 @@ sub iterator {
 	for (0 .. $#row_slice) {
 		if (!ref $row_slice[$_]) {
 			my $field= $col_map->[$row_slice[$_]];
-			push @trim_idx, $_ if $field->trim;
+			if (my $t= $field->trim_coderef) {
+				$trimmer{$t} ||= [ $t, [] ];
+				push @{ $trimmer{$t}[1] }, $_;
+			}
 			push @blank_val, $field->blank;
 			push @type_check, $self->_make_validation_callback($field, $_)
 				if $field->type;
@@ -538,13 +551,17 @@ sub iterator {
 			push @arrayvals, [ $_, $from, scalar @$src ];
 			for ($from .. $#row_slice) {
 				my $field= $col_map->[$row_slice[$_]];
-				push @trim_idx, $_ if $field->trim;
+				if (my $t= $field->trim_coderef) {
+					$trimmer{$t} ||= [ $t, [] ];
+					push @{ $trimmer{$t}[1] }, $_;
+				}
 				push @blank_val, $field->blank;
 				push @type_check, $self->_make_validation_callback($field, $_)
 					if $field->type;
 			}
 		}
 	}
+	my @trim= values %trimmer;
 	@arrayvals= reverse @arrayvals;
 	my ($n_blank, $first_blank, $eof);
 	my $sub= sub {
@@ -553,9 +570,8 @@ sub iterator {
 		my $row= !$eof && $data_iter->(\@row_slice)
 			or ++$eof && return undef;
 		# Apply 'trim' to any column whose field requested it
-		for (grep { defined } @{$row}[@trim_idx]) {
-			$_ =~ s/\s+$//;
-			$_ =~ s/^\s+//;
+		for my $t (@trim) {
+			$t->[0]->() for grep defined, @{$row}[@{$t->[1]}];
 		}
 		# Apply 'blank value' to every column which is zero length
 		$n_blank= 0;
@@ -566,6 +582,7 @@ sub iterator {
 			$first_blank ||= $data_iter->position;
 			goto again;
 		} elsif ($first_blank) {
+			# At the end of a series of blank rows, run the callback to decide what to do
 			unless ($self->_handle_blank_row($first_blank, $data_iter->position)) {
 				$eof= 1;
 				return undef;
@@ -597,15 +614,26 @@ sub iterator {
 sub _make_validation_callback {
 	my ($self, $field, $index)= @_;
 	my $t= $field->type;
-	ref $t eq 'CODE'? sub {
-		my $e= $t->($_[0][$index]);
-		defined $e? ([ $field, $index, $e ]) : ()
+	my $c= $field->coerce;
+	$index =~ /^[0-9]+\Z/ or die "$index"; # sanity check for security, since using eval
+	# The validate can either be Type::Tiny or a coderef that inspects $_ and returns the error.
+	my $validate_fn= ref $t eq 'CODE'? '$t->'
+		: $t->can('validate')         ? '$t->validate'
+		: croak "Invalid type constraint $t on field ".$field->name;
+	# Coerce can either be Type::Tiny or a coderef that inspects $_[0] and returns the coerced value.
+	my $coerce_fn= ref $c eq 'CODE'? '$c->'
+		: $c && (!$t->can('has_coercions') || $t->has_coercions)? '$t->coerce'
+		: undef;
+	my $field_lvalue= '$_[0]['.$index.']';
+	my $code= 'sub { my $e= '.$validate_fn.'('.$field_lvalue.'); ';
+	if (defined $coerce_fn) {
+		$code .= 'if (defined $e) {'
+		      .  '  my $tmp= '.$coerce_fn.'('.$field_lvalue.');'
+		      .  '  ('.$field_lvalue.', $e)= ($tmp) unless defined '.$validate_fn.'($tmp);'
+		      .  '}';
 	}
-	: $t->can('validate')? sub {
-		my $e= $t->validate($_[0][$index]);
-		defined $e? ([ $field, $index, $e ]) : ()
-	}
-	: croak "Invalid type constraint $t on field ".$field->name;
+	$code .= 'defined $e? ([ $field, '.$index.', $e ]) : () }';
+	return eval($code) || die "error compiling validation callback: $@";
 }
 
 sub _handle_blank_row {
@@ -671,7 +699,7 @@ sub Data::TableReader::_RecIter::seek {
 }
 sub Data::TableReader::_RecIter::next_dataset {
 	shift->_fields->{reader}->_log
-		->('warn',"Searching for supsequent table headers is not supported yet");
+		->('warn',"Searching for subsequent table headers is not supported yet");
 	return 0;
 }
 
@@ -689,7 +717,7 @@ Data::TableReader - Extract records from "dirty" tabular data sources
 
 =head1 VERSION
 
-version 0.009
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -703,7 +731,7 @@ version 0.009
     )
     ->iterator->all;
 
-but there's plenty of options to choose from...
+but there are plenty of options to choose from...
 
   my $tr= Data::TableReader->new(
     # path or file handle
@@ -712,11 +740,11 @@ but there's plenty of options to choose from...
     
     # We want these fields to exist in the file (identified by headers)
     fields => [
-      { name => 'address', header => qw/street|address/i },
+      { name => 'address', header => qr/street|address/i },
       'city',
       'state',
       # can validate with Type::Tiny classes
-      { name => 'zip', header => qw/zip\b|postal/i, type => US_Zipcode },
+      { name => 'zip', header => qr/zip\b|postal/i, type => US_Zipcode },
     ],
     
     # Our data provider is horrible; just ignore any nonsense we encounter
@@ -733,22 +761,24 @@ but there's plenty of options to choose from...
 
 =head1 DESCRIPTION
 
-This module is designed to be a useful for anyone who needs to take "loose"
-or "dirty" tabular data sources (such as Excel, CSV, TSV, or HTML) which may
-have been edited by non-technical humans and extract the data into sanitized
-records, while also verifying that the data file contains roughly the schema
-you were expecting.  It is primarily intended for making automated imports
-of data from non-automated or unstable sources, and providing human-readable
-feedback about the validity of the data file.
+This module is designed to take "loose" or "dirty" tabular data sources
+(such as Excel, CSV, TSV, or HTML) which may have been edited by non-technical
+humans and extract the data into sanitized records, while also verifying that
+the data file contains roughly the schema you were expecting.  It is primarily
+intended for making automated imports of data from non-automated or unstable
+sources, and providing human-readable feedback about the validity of the data
+file.
 
 =head1 ATTRIBUTES
 
 =head2 input
 
-This can be a file name or L<Path::Class> instance or file handle or a
-L<Spreadsheet::ParseExcel::Worksheet> object.  If a file handle, it must be
-seekable in order to auto-detect the file format, I<or> you may specify the
-decoder directly to avoid auto-detection.
+This can be a file name, L<Path::Class> instance, file handle, arrayref, or
+L<Spreadsheet::ParseExcel::Worksheet> object.  If you supply a file handle,
+it must be seekable in order to auto-detect the file format, I<or> you may
+specify the decoder directly to avoid auto-detection.  Arrayrefs are passed to
+the L<'Mock' decoder|Data::TableReader::Decoder::Mock> which just returns the
+data as-is.
 
 =head2 decoder
 
@@ -774,9 +804,13 @@ Examples:
 
 =head2 fields
 
-An arrayref of L<Data::TableReader::Field> objects (or hashrefs to
-construct them with) which this module should search for within the tables
-(worksheets etc.) of L</input>.
+An arrayref of L<Data::TableReader::Field> objects which this module should
+search for within the tables (worksheets etc.) of L</input>.
+
+If an element of this array is a hashref or string, it will be coerced to an
+instance of L<Data::TableReader::Field>, with plain strings becoming the
+C<name> attribute.  See L<Data::TableReader::Field/header> for how names are
+automatically converted to the header-matching regex.
 
 =head2 record_class
 
@@ -974,7 +1008,9 @@ returns all records in an arrayref.
 
 =head1 THANKS
 
-Portions of this software were funded by L<Ellis, Partners in Management Solutions|http://www.epmsonline.com/>.
+Portions of this software were funded by
+L<Ellis, Partners in Management Solutions|http://www.epmsonline.com/>
+and L<Candela Corporation|https://www.candelacorp.com/>.
 
 =head1 AUTHOR
 
@@ -988,7 +1024,7 @@ Christian Walde <walde.christian@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Michael Conrad.
+This software is copyright (c) 2024 by Michael Conrad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
