@@ -1,10 +1,9 @@
 package Data::TableReader::Decoder::XLS;
-$Data::TableReader::Decoder::XLS::VERSION = '0.009';
 use Moo 2;
 use Carp;
 extends 'Data::TableReader::Decoder::Spreadsheet';
 
-our @xls_probe_modules= qw( Spreadsheet::ParseExcel );
+our @xls_probe_modules= ( [ 'Spreadsheet::ParseExcel', '0.66' ] );
 our $default_xls_module;
 sub default_xls_module {
 	$default_xls_module ||=
@@ -12,6 +11,7 @@ sub default_xls_module {
 }
 
 # ABSTRACT: Access sheets/rows of a Microsoft Excel '97 workbook
+our $VERSION = '0.012'; # VERSION
 
 
 sub _build_workbook {
@@ -42,7 +42,7 @@ Data::TableReader::Decoder::XLS - Access sheets/rows of a Microsoft Excel '97 wo
 
 =head1 VERSION
 
-version 0.009
+version 0.012
 
 =head1 DESCRIPTION
 
@@ -65,7 +65,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Michael Conrad.
+This software is copyright (c) 2024 by Michael Conrad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
