@@ -1,11 +1,10 @@
 package Data::TableReader::Decoder::XLSX;
-$Data::TableReader::Decoder::XLSX::VERSION = '0.009';
 use Moo 2;
 use Carp;
 use Try::Tiny;
 extends 'Data::TableReader::Decoder::Spreadsheet';
 
-our @xlsx_probe_modules= qw( Spreadsheet::ParseXLSX Spreadsheet::XLSX );
+our @xlsx_probe_modules= ( [ 'Spreadsheet::ParseXLSX', '0.30' ], 'Spreadsheet::XLSX' );
 our $default_xlsx_module;
 sub default_xlsx_module {
 	$default_xlsx_module ||=
@@ -13,6 +12,7 @@ sub default_xlsx_module {
 }
 
 # ABSTRACT: Access sheets/rows of a modern Microsoft Excel workbook
+our $VERSION = '0.012'; # VERSION
 
 
 sub _build_workbook {
@@ -49,7 +49,7 @@ Data::TableReader::Decoder::XLSX - Access sheets/rows of a modern Microsoft Exce
 
 =head1 VERSION
 
-version 0.009
+version 0.012
 
 =head1 DESCRIPTION
 
@@ -72,7 +72,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Michael Conrad.
+This software is copyright (c) 2024 by Michael Conrad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
